@@ -603,14 +603,16 @@ class ChatGPT:
 
         return await self.return_chat_url()
         
-    async def backtrack_chat(self,conversation_id: str,loop_text:str) -> bool:
+    async def backtrack_chat(self,loop_text:str,conversation_id: str = "") -> bool:
         '''
         backtrack the chat,
         conversation_id : conversation_id,
         loop_text: history messages you have sent in this conversation,
         return bool
         '''
-        
+        if conversation_id == "":
+            conversation_id = self.__conversation_id
+            
         await self.cf(conversation_id)
         
         self.driver.get(self.driver.current_url)
@@ -802,16 +804,16 @@ class ChatGPT:
                         
                 elif msg_send["type"] == "loop":
                     try:
-                        msg_send["msg_rec"] = self.backtrack_chat(msg_send["conversation_id"],msg_send["msg_send"])
+                        msg_send["msg_rec"] = await self.backtrack_chat(msg_send["msg_send"],msg_send["conversation_id"])
                     except:
                         
                         msg_send["msg_rec"] = False
                 elif msg_send["type"] == "init":
                     try:
-                        msg_send["msg_rec"] = self.init_personality()
+                        msg_send["msg_rec"] = await self.init_personality(bool(msg_send["msg_send"]),msg_send["conversation_id"])
                     except:
                         
-                        msg_send["msg_rec"] = {"status":False,"conversation_id":"失败了"}
+                        msg_send["msg_rec"] = {"status":False,"conversation_id":""}
                     
                 self.rec.append(msg_send)
     
@@ -820,15 +822,18 @@ class ChatGPT:
         self.msg_id += 1
         return self.msg_id
                 
-    async def async_send_message(self,conversation_id,msg):
+    async def async_send_message(self,msg,conversation_id:str = "",msg_type: str = "msg") -> dict:
         '''async send_message,
         conversation_id: conversation_id,
         msg: your message to gpt.
         returns a dictionary containing the conversation id and the reply
         '''
+        if conversation_id == "":
+            conversation_id = self.__conversation_id
+            
         msg_dict = {
             "id":await self.get_id(), 
-            "type":"msg",
+            "type":msg_type,
             "msg":msg,
             "conversation_id":conversation_id
         }
